/**
 * Enumerates possible tooltip positions
 *
 * @public
 */
export declare const TooltipPosition: {
    /**
     * The tooltip is positioned above the element
     */
    readonly top: "top";
    /**
     * The tooltip is positioned to the right of the element
     */
    readonly right: "right";
    /**
     * The tooltip is positioned below the element
     */
    readonly bottom: "bottom";
    /**
     * The tooltip is positioned to the left of the element
     */
    readonly left: "left";
    /**
     * The tooltip is positioned in the center of the element
     */
    readonly center: "center";
    /**
     * The tooltip is positioned before the element
     */
    readonly start: "start";
    /**
     * The tooltip is positioned after the element
     */
    readonly end: "end";
    /**
     * The tooltip is positioned above the element and to the left
     */
    readonly topLeft: "top-left";
    /**
     * The tooltip is positioned above the element and horizontally centered
     */
    readonly topCenter: "top-center";
    /**
     * The tooltip is positioned above the element and to the right
     */
    readonly topRight: "top-right";
    /**
     * The tooltip is positioned below the element and to the left
     */
    readonly bottomLeft: "bottom-left";
    /**
     * The tooltip is positioned below the element and horizontally centered
     */
    readonly bottomCenter: "bottom-center";
    /**
     * The tooltip is positioned below the element and to the right
     */
    readonly bottomRight: "bottom-right";
    /**
     * The tooltip is positioned above the element and to the left
     */
    readonly topStart: "top-start";
    /**
     * The tooltip is positioned above the element and to the right
     */
    readonly topEnd: "top-end";
    /**
     * The tooltip is positioned below the element and to the left
     */
    readonly bottomStart: "bottom-start";
    /**
     * The tooltip is positioned below the element and to the right
     */
    readonly bottomEnd: "bottom-end";
};
/**
 * The possible tooltip positions
 *
 * @public
 */
export declare type TooltipPosition = typeof TooltipPosition[keyof typeof TooltipPosition];
